/* =========================================================
 VARIABLE
========================================================= */

var gulp = require('gulp');
var sass = require('gulp-sass');
var browserSync = require('browser-sync').create();
var plumber = require('gulp-plumber');
var notify = require('gulp-notify');
var inlineCss = require('gulp-inline-css');
var runSequence = require('run-sequence');
var src = './src';
var dist = './dist';

var paths = {
  'scss': src + '/**/css/',
  'css' : src
}

var options = {

  serve : {
    open: 'external',
    port: 3000,
    ui: false,
    server: {
      baseDir: dist
    }
  },

  sass : {
    errLogToConsole: true,
    outputStyle: 'compressed'
  },

  inlineCss : {
    applyStyleTags: false,
    removeStyleTags: false
  },

  watch : [
    dist + '/**/*.html',
    dist + '/**/*.php'
  ]

}


/* =========================================================
 BROWSER SYNC
========================================================= */

gulp.task('serve', () => {
  browserSync.init(options.serve);
});

/* =========================================================
 SASS
========================================================= */

gulp.task('sass', () => {
  return gulp
    .src(paths.scss + '**/*.scss')
    .pipe(plumber({
      errorHandler: notify.onError('<%= error.message %>')
    }))
    .pipe(sass(options.sass).on('error', sass.logError))
    .pipe(gulp.dest(paths.css))
    .pipe(browserSync.reload({stream: true}))
});

/* =========================================================
 INLINE CSS
========================================================= */

gulp.task('inlineCss', () => {
  return gulp.src(src + '/**/*.html')
  .pipe(plumber({
    errorHandler: notify.onError('<%= error.message %>')
  }))
  .pipe(inlineCss(options.inlineCss))
  .pipe(gulp.dest(dist))
});

/* =========================================================
 RUN SEQUENCE
========================================================= */

gulp.task('production', function(callback) {
  return runSequence('sass', 'inlineCss', callback);
});

/* =========================================================
 WATCH
========================================================= */

gulp.task('watch', () => {

  // scssファイルが変更されたらproductionタスクを実行
  gulp.watch(paths.scss + '**/*.scss', ['production']);

  // htmlファイルが変更されたらinlineCssタスクを実行
  gulp.watch(src + '**/*.html', ['inlineCss']);

  // html,phpファイルが変更されたら、ブラウザをリロード
  gulp.watch(options.watch).on('change', browserSync.reload);

});

gulp.task('default', ['serve', 'watch']);